=====
Array
=====

The following methods are available under the `Series.arr` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Series.arr.all
    Series.arr.any
    Series.arr.arg_max
    Series.arr.arg_min
    Series.arr.contains
    Series.arr.count_matches
    Series.arr.explode
    Series.arr.first
    Series.arr.get
    Series.arr.join
    Series.arr.last
    Series.arr.max
    Series.arr.median
    Series.arr.min
    Series.arr.n_unique
    Series.arr.reverse
    Series.arr.shift
    Series.arr.sort
    Series.arr.std
    Series.arr.sum
    Series.arr.to_list
    Series.arr.to_struct
    Series.arr.unique
    Series.arr.var
